@@ -39,10 +39,15 @@ from .._exceptions import BadTypeInNameException
 from .._logger import log
 from .._protocol.outgoing import DNSOutgoing
 from .._updates import RecordUpdate, RecordUpdateListener
-from .._utils.asyncio import get_running_loop, run_coro_with_timeout
+from .._utils.asyncio import (
+    _resolve_all_futures_to_none,
+    get_running_loop,
+    run_coro_with_timeout,
+    wait_for_future_set_or_timeout,
+)
 from .._utils.name import service_type_name
 from .._utils.net import IPVersion, _encode_address
-from .._utils.time import current_time_millis, millis_to_seconds
+from .._utils.time import current_time_millis
 from ..const import (
     _ADDRESS_RECORD_TYPES,
     _CLASS_IN,
@@ -89,12 +94,6 @@ def instance_name_from_service_info(info: "ServiceInfo", strict: bool = True) ->
 _cached_ip_addresses = lru_cache(maxsize=256)(ip_address)
 
 
-def _set_future_none_if_not_done(fut: asyncio.Future) -> None:
-    """Set a future to None if it is not done."""
-    if not fut.done():  # pragma: no branch
-        fut.set_result(None)
-
-
 class ServiceInfo(RecordUpdateListener):
     """Service information.
 
@@ -180,7 +179,7 @@ class ServiceInfo(RecordUpdateListener):
         self.host_ttl = host_ttl
         self.other_ttl = other_ttl
         self.interface_index = interface_index
-        self._new_records_futures: List[asyncio.Future] = []
+        self._new_records_futures: Set[asyncio.Future] = set()
 
     @property
     def name(self) -> str:
@@ -242,14 +241,9 @@ class ServiceInfo(RecordUpdateListener):
 
     async def async_wait(self, timeout: float) -> None:
         """Calling task waits for a given number of milliseconds or until notified."""
-        loop = asyncio.get_running_loop()
-        future = loop.create_future()
-        self._new_records_futures.append(future)
-        handle = loop.call_later(millis_to_seconds(timeout), _set_future_none_if_not_done, future)
-        try:
-            await future
-        finally:
-            handle.cancel()
+        loop = get_running_loop()
+        assert loop is not None
+        await wait_for_future_set_or_timeout(loop, self._new_records_futures, timeout)
 
     def addresses_by_version(self, version: IPVersion) -> List[bytes]:
         """List addresses matching IP version.
@@ -367,20 +361,11 @@ class ServiceInfo(RecordUpdateListener):
             strs.append(text[index : index + length])
             index += length
 
-        key: bytes
-        value: Optional[bytes]
         for s in strs:
-            key_value = s.split(b'=', 1)
-            if len(key_value) == 2:
-                key, value = key_value
-            else:
-                # No equals sign at all
-                key = s
-                value = None
-
+            key, _, value = s.partition(b'=')
             # Only update non-existent properties
             if key and key not in result:
-                result[key] = value
+                result[key] = value or None
 
         # Properties should be set atomically
         # in case another thread is reading them
@@ -441,11 +426,9 @@ class ServiceInfo(RecordUpdateListener):
 
         This method will be run in the event loop.
         """
-        if self._process_records_threadsafe(zc, now, records) and self._new_records_futures:
-            for future in self._new_records_futures:
-                if not future.done():
-                    future.set_result(None)
-            self._new_records_futures.clear()
+        new_records_futures = self._new_records_futures
+        if self._process_records_threadsafe(zc, now, records) and new_records_futures:
+            _resolve_all_futures_to_none(new_records_futures)
 
     def _process_records_threadsafe(self, zc: 'Zeroconf', now: float, records: List[RecordUpdate]) -> bool:
         """Thread safe record updating.
